wifi-backup
===========

## Usage

```
Usage: wifi [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  backup  Backup all wifi connections from NetworkManager.
  import  Import wifi connections from a file to the NetworkManager.
```
